summaryrefslogtreecommitdiff
path: root/src/KM_util.h
diff options
context:
space:
mode:
authormsheby <msheby@cinecert.com>2009-03-28 04:42:36 +0000
committermsheby <>2009-03-28 04:42:36 +0000
commit55e9d7f9fd598b1bfb9ee46ea0cfc971f88dd800 (patch)
tree876ad4c9f73dbf00322aa18e0e099985e3410ada /src/KM_util.h
parent213c1015cd54bd3539a7e28fd004419dcf31e007 (diff)
Add AddMinutes() function.
Allow negative input to AddHours() and AddDays() in Windows implementation. Allow parsing of non-zero minutes in time offset values. Allow parsing of "Z" as time offset value.
Diffstat (limited to 'src/KM_util.h')
-rwxr-xr-xsrc/KM_util.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/KM_util.h b/src/KM_util.h
index d8b9bb3..8dd573f 100755
--- a/src/KM_util.h
+++ b/src/KM_util.h
@@ -362,7 +362,7 @@ namespace Kumu
void GenRandomValue(SymmetricKey&);
//
- // 2004-05-01T13:20:00-00:00
+ // 2004-05-01T13:20:00+00:00
const ui32_t DateTimeLen = 25; // the number of chars in the xs:dateTime format (sans milliseconds)
// UTC time+date representation
@@ -387,17 +387,18 @@ namespace Kumu
bool operator==(const Timestamp& rhs) const;
bool operator!=(const Timestamp& rhs) const;
- // Write the timestamp value to the given buffer in the form 2004-05-01T13:20:00-00:00
+ // Write the timestamp value to the given buffer in the form 2004-05-01T13:20:00+00:00
// returns 0 if the buffer is smaller than DateTimeLen
const char* EncodeString(char* str_buf, ui32_t buf_len) const;
// decode and set value from string formatted by EncodeString
bool DecodeString(const char* datestr);
// Add the given number of days or hours to the timestamp value.
// Values less than zero will cause the timestamp to decrease
void AddDays(i32_t);
void AddHours(i32_t);
+ void AddMinutes(i32_t);
// Read and write the timestamp value as a byte string having
// the following format:
@@ -387,17 +387,18 @@ namespace Kumu
// decode and set value from string formatted by EncodeString
bool DecodeString(const char* datestr);
- // Add the given number of days or hours to the timestamp value.
+ // Add the given number of days, hours, or minutes to the timestamp value.
// Values less than zero will cause the timestamp to decrease
void AddDays(i32_t);